# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from bilireq.grpc.protos.pgc.gateway.vega.v1 import vega_pb2 as pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2


class VegaStub(object):
    """
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateTunnel = channel.unary_unary(
                '/pgc.gateway.vega.v1.Vega/CreateTunnel',
                request_serializer=pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.VegaFrame.SerializeToString,
                response_deserializer=pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.VegaFrame.FromString,
                )


class VegaServicer(object):
    """
    """

    def CreateTunnel(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VegaServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateTunnel': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTunnel,
                    request_deserializer=pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.VegaFrame.FromString,
                    response_serializer=pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.VegaFrame.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'pgc.gateway.vega.v1.Vega', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Vega(object):
    """
    """

    @staticmethod
    def CreateTunnel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pgc.gateway.vega.v1.Vega/CreateTunnel',
            pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.VegaFrame.SerializeToString,
            pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.VegaFrame.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class VegaFrameDocStub(object):
    """
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Auth = channel.unary_unary(
                '/pgc.gateway.vega.v1.VegaFrameDoc/Auth',
                request_serializer=pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.AuthReq.SerializeToString,
                response_deserializer=pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.AuthResp.FromString,
                )
        self.Heartbeat = channel.unary_unary(
                '/pgc.gateway.vega.v1.VegaFrameDoc/Heartbeat',
                request_serializer=pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.HeartbeatReq.SerializeToString,
                response_deserializer=pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.HeartbeatResp.FromString,
                )
        self.MessageAck = channel.unary_unary(
                '/pgc.gateway.vega.v1.VegaFrameDoc/MessageAck',
                request_serializer=pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.MessageAckReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.Subscribe = channel.unary_unary(
                '/pgc.gateway.vega.v1.VegaFrameDoc/Subscribe',
                request_serializer=pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.SubscribeReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class VegaFrameDocServicer(object):
    """
    """

    def Auth(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Heartbeat(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageAck(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Subscribe(self, request, context):
        """
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VegaFrameDocServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Auth': grpc.unary_unary_rpc_method_handler(
                    servicer.Auth,
                    request_deserializer=pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.AuthReq.FromString,
                    response_serializer=pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.AuthResp.SerializeToString,
            ),
            'Heartbeat': grpc.unary_unary_rpc_method_handler(
                    servicer.Heartbeat,
                    request_deserializer=pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.HeartbeatReq.FromString,
                    response_serializer=pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.HeartbeatResp.SerializeToString,
            ),
            'MessageAck': grpc.unary_unary_rpc_method_handler(
                    servicer.MessageAck,
                    request_deserializer=pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.MessageAckReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'Subscribe': grpc.unary_unary_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.SubscribeReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'pgc.gateway.vega.v1.VegaFrameDoc', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class VegaFrameDoc(object):
    """
    """

    @staticmethod
    def Auth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pgc.gateway.vega.v1.VegaFrameDoc/Auth',
            pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.AuthReq.SerializeToString,
            pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.AuthResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Heartbeat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pgc.gateway.vega.v1.VegaFrameDoc/Heartbeat',
            pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.HeartbeatReq.SerializeToString,
            pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.HeartbeatResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MessageAck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pgc.gateway.vega.v1.VegaFrameDoc/MessageAck',
            pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.MessageAckReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pgc.gateway.vega.v1.VegaFrameDoc/Subscribe',
            pgc_dot_gateway_dot_vega_dot_v1_dot_vega__pb2.SubscribeReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/view/v1/view.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from bilireq.grpc.protos.bilibili.app.archive.middleware.v1 import preload_pb2 as bilibili_dot_app_dot_archive_dot_middleware_dot_v1_dot_preload__pb2
from bilireq.grpc.protos.bilibili.app.archive.v1 import archive_pb2 as bilibili_dot_app_dot_archive_dot_v1_dot_archive__pb2
from bilireq.grpc.protos.bilibili.pagination import pagination_pb2 as bilibili_dot_pagination_dot_pagination__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x62ilibili/app/view/v1/view.proto\x12\x14\x62ilibili.app.view.v1\x1a\x19google/protobuf/any.proto\x1a\x30\x62ilibili/app/archive/middleware/v1/preload.proto\x1a%bilibili/app/archive/v1/archive.proto\x1a$bilibili/pagination/pagination.proto\"\xcf\x01\n\x10\x41\x63tivityResource\x12\x15\n\rmod_pool_name\x18\x01 \x01(\t\x12\x19\n\x11mod_resource_name\x18\x02 \x01(\t\x12\x10\n\x08\x62g_color\x18\x03 \x01(\t\x12\x19\n\x11selected_bg_color\x18\x04 \x01(\t\x12\x12\n\ntext_color\x18\x05 \x01(\t\x12\x18\n\x10light_text_color\x18\x06 \x01(\t\x12\x17\n\x0f\x64\x61rk_text_color\x18\x07 \x01(\t\x12\x15\n\rdivider_color\x18\x08 \x01(\t\"\xa3\x0b\n\x0e\x41\x63tivitySeason\x12)\n\x03\x61rc\x18\x01 \x01(\x0b\x32\x1c.bilibili.app.archive.v1.Arc\x12-\n\x05pages\x18\x02 \x03(\x0b\x32\x1e.bilibili.app.view.v1.ViewPage\x12\x31\n\towner_ext\x18\x03 \x01(\x0b\x32\x1e.bilibili.app.view.v1.OnwerExt\x12/\n\x08req_user\x18\x04 \x01(\x0b\x32\x1d.bilibili.app.view.v1.ReqUser\x12\x31\n\telec_rank\x18\x05 \x01(\x0b\x32\x1e.bilibili.app.view.v1.ElecRank\x12.\n\x07history\x18\x06 \x01(\x0b\x32\x1d.bilibili.app.view.v1.History\x12\x0c\n\x04\x62vid\x18\x07 \x01(\t\x12*\n\x05honor\x18\x08 \x01(\x0b\x32\x1b.bilibili.app.view.v1.Honor\x12*\n\x05staff\x18\t \x03(\x0b\x32\x1b.bilibili.app.view.v1.Staff\x12\x33\n\nugc_season\x18\n \x01(\x0b\x32\x1f.bilibili.app.view.v1.UgcSeason\x12&\n\x03tab\x18\x0b \x01(\x0b\x32\x19.bilibili.app.view.v1.Tab\x12(\n\x04rank\x18\x0c \x01(\x0b\x32\x1a.bilibili.app.view.v1.Rank\x12*\n\x05order\x18\r \x01(\x0b\x32\x1b.bilibili.app.view.v1.Order\x12\x17\n\x0fsupport_dislike\x18\x0e \x01(\x08\x12?\n\x10operation_relate\x18\x0f \x01(\x0b\x32%.bilibili.app.view.v1.OperationRelate\x12\x41\n\x11\x61\x63tivity_resource\x18\x10 \x01(\x0b\x32&.bilibili.app.view.v1.ActivityResource\x12\x12\n\nshort_link\x18\x11 \x01(\t\x12*\n\x05label\x18\x12 \x01(\x0b\x32\x1b.bilibili.app.view.v1.Label\x12.\n\x07\x64islike\x18\x13 \x01(\x0b\x32\x1d.bilibili.app.view.v1.Dislike\x12\x35\n\x0bplayer_icon\x18\x14 \x01(\x0b\x32 .bilibili.app.view.v1.PlayerIcon\x12\x16\n\x0eshare_subtitle\x18\x15 \x01(\t\x12\x31\n\tcm_config\x18\x16 \x01(\x0b\x32\x1e.bilibili.app.view.v1.CMConfig\x12\x44\n\x13tf_panel_customized\x18\x17 \x01(\x0b\x32\'.bilibili.app.view.v1.TFPanelCustomized\x12\x11\n\targue_msg\x18\x18 \x01(\t\x12*\n\x05\x65\x63ode\x18\x19 \x01(\x0e\x32\x1b.bilibili.app.view.v1.ECode\x12\x39\n\rcustom_config\x18\x1a \x01(\x0b\x32\".bilibili.app.view.v1.CustomConfig\x12\x11\n\tbadge_url\x18\x1b \x01(\t\x12-\n\x07\x64\x65sc_v2\x18\x1c \x03(\x0b\x32\x1c.bilibili.app.view.v1.DescV2\x12,\n\x06\x63onfig\x18\x1d \x01(\x0b\x32\x1c.bilibili.app.view.v1.Config\x12,\n\x06online\x18\x1e \x01(\x0b\x32\x1c.bilibili.app.view.v1.Online\x12\x31\n\tarc_extra\x18\x1f \x01(\x0b\x32\x1e.bilibili.app.view.v1.ArcExtra\x12\x37\n\rreply_preface\x18  \x01(\x0b\x32 .bilibili.app.view.v1.ReplyStyle\"<\n\x0e\x41\x64\x64\x43ontractReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0e\n\x06up_mid\x18\x02 \x01(\x03\x12\r\n\x05spmid\x18\x03 \x01(\t\"\xa6\x01\n\x06\x41\x64Info\x12\x13\n\x0b\x63reative_id\x18\x01 \x01(\x03\x12\x15\n\rcreative_type\x18\x02 \x01(\x03\x12?\n\x10\x63reative_content\x18\x03 \x01(\x0b\x32%.bilibili.app.view.v1.CreativeContent\x12\r\n\x05\x61\x64_cb\x18\x04 \x01(\t\x12\x11\n\tcard_type\x18\x05 \x01(\x05\x12\r\n\x05\x65xtra\x18\x06 \x01(\x0c\"$\n\x08\x41rcExtra\x12\x18\n\x10\x61rc_pub_location\x18\x01 \x01(\t\"\x93\x01\n\nArcsPlayer\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x45\n\x0bplayer_info\x18\x02 \x03(\x0b\x32\x30.bilibili.app.view.v1.ArcsPlayer.PlayerInfoEntry\x1a\x31\n\x0fPlayerInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x01\n\x05\x41sset\x12\x0c\n\x04paid\x18\x01 \x01(\x05\x12\r\n\x05price\x18\x02 \x01(\x03\x12+\n\x03msg\x18\x03 \x01(\x0b\x32\x1e.bilibili.app.view.v1.AssetMsg\x12\x33\n\x0bpreview_msg\x18\x04 \x01(\x0b\x32\x1e.bilibili.app.view.v1.AssetMsg\"(\n\x08\x41ssetMsg\x12\r\n\x05\x64\x65sc1\x18\x01 \x01(\t\x12\r\n\x05\x64\x65sc2\x18\x02 \x01(\t\"O\n\tAttention\x12\x12\n\nstart_time\x18\x01 \x01(\x05\x12\x10\n\x08\x65nd_time\x18\x02 \x01(\x05\x12\r\n\x05pos_x\x18\x03 \x01(\x01\x12\r\n\x05pos_y\x18\x04 \x01(\x01\"\x9a\x01\n\x05\x41udio\x12\r\n\x05title\x18\x01 \x01(\t\x12\x11\n\tcover_url\x18\x02 \x01(\t\x12\x0f\n\x07song_id\x18\x03 \x01(\x03\x12\x12\n\nplay_count\x18\x04 \x01(\x03\x12\x13\n\x0breply_count\x18\x05 \x01(\x03\x12\x10\n\x08upper_id\x18\x06 \x01(\x03\x12\x10\n\x08\x65ntrance\x18\x07 \x01(\t\x12\x11\n\tsong_attr\x18\x08 \x01(\x03\"\xb6\x01\n\nBadgeStyle\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x06 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x07 \x01(\t\x12\x10\n\x08\x62g_style\x18\x08 \x01(\x05\"^\n\x03\x42gm\x12\x0b\n\x03sid\x18\x01 \x01(\x03\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\x12\x0f\n\x07jumpUrl\x18\x05 \x01(\t\x12\r\n\x05\x63over\x18\x06 \x01(\t\"&\n\x11\x42izFavSeasonParam\x12\x11\n\tseason_id\x18\x01 \x01(\x03\"(\n\x13\x42izFollowVideoParam\x12\x11\n\tseason_id\x18\x01 \x01(\x03\"\x1f\n\x10\x42izJumpLinkParam\x12\x0b\n\x03url\x18\x01 \x01(\t\"k\n\x17\x42izReserveActivityParam\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0b\n\x03oid\x18\x04 \x01(\x03\x12\x12\n\nreserve_id\x18\x05 \x01(\x03\"&\n\x13\x42izReserveGameParam\x12\x0f\n\x07game_id\x18\x01 \x01(\x03\"2\n\x06\x42utton\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\"\x86\x01\n\x0b\x42uttonStyle\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x11\n\tjump_link\x18\x06 \x01(\t\"\xb9\x01\n\x0e\x42uzzwordConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\x05\x12\r\n\x05start\x18\x04 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x05 \x01(\x03\x12\x16\n\x0e\x66ollow_control\x18\x06 \x01(\x08\x12\n\n\x02id\x18\x07 \x01(\x03\x12\x13\n\x0b\x62uzzword_id\x18\x08 \x01(\x03\x12\x13\n\x0bschema_type\x18\t \x01(\x05\x12\x0f\n\x07picture\x18\n \x01(\t\"\xf4\x04\n\x0e\x43\x61\x63heViewReply\x12)\n\x03\x61rc\x18\x01 \x01(\x0b\x32\x1c.bilibili.app.archive.v1.Arc\x12-\n\x05pages\x18\x02 \x03(\x0b\x32\x1e.bilibili.app.view.v1.ViewPage\x12\x31\n\towner_ext\x18\x03 \x01(\x0b\x32\x1e.bilibili.app.view.v1.OnwerExt\x12/\n\x08req_user\x18\x04 \x01(\x0b\x32\x1d.bilibili.app.view.v1.ReqUser\x12,\n\x06season\x18\x05 \x01(\x0b\x32\x1c.bilibili.app.view.v1.Season\x12\x31\n\telec_rank\x18\x06 \x01(\x0b\x32\x1e.bilibili.app.view.v1.ElecRank\x12.\n\x07history\x18\x07 \x01(\x0b\x32\x1d.bilibili.app.view.v1.History\x12.\n\x07\x64islike\x18\x08 \x01(\x0b\x32\x1d.bilibili.app.view.v1.Dislike\x12\x35\n\x0bplayer_icon\x18\t \x01(\x0b\x32 .bilibili.app.view.v1.PlayerIcon\x12\x0c\n\x04\x62vid\x18\n \x01(\t\x12\x12\n\nshort_link\x18\x0b \x01(\t\x12\x16\n\x0eshare_subtitle\x18\x0c \x01(\t\x12\x44\n\x13tf_panel_customized\x18\r \x01(\x0b\x32\'.bilibili.app.view.v1.TFPanelCustomized\x12,\n\x06online\x18\x0e \x01(\x0b\x32\x1c.bilibili.app.view.v1.Online\"}\n\x0c\x43\x61\x63heViewReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\x12\x0f\n\x07trackid\x18\x04 \x01(\t\x12\x10\n\x08\x61\x64_extra\x18\x05 \x01(\t\x12\r\n\x05spmid\x18\x06 \x01(\t\x12\x12\n\nfrom_spmid\x18\x07 \x01(\t\"2\n\x07\x43hronos\x12\x0b\n\x03md5\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\x12\x0c\n\x04sign\x18\x03 \x01(\t\"V\n\rChronosPkgReq\x12\x13\n\x0bservice_key\x18\x01 \x01(\t\x12\x16\n\x0e\x65ngine_version\x18\x02 \x01(\t\x12\x18\n\x10message_protocol\x18\x03 \x01(\t\"\xfa\x01\n\x16\x43lickActivitySeasonReq\x12\x31\n\norder_type\x18\x01 \x01(\x0e\x32\x1d.bilibili.app.view.v1.BizType\x12\r\n\x05spmid\x18\x02 \x01(\t\x12@\n\x07reserve\x18\x03 \x01(\x0b\x32-.bilibili.app.view.v1.BizReserveActivityParamH\x00\x12=\n\nfav_season\x18\x04 \x01(\x0b\x32\'.bilibili.app.view.v1.BizFavSeasonParamH\x00\x12\x0e\n\x06\x61\x63tion\x18\x05 \x01(\x03\x42\r\n\x0border_param\"\'\n\x14\x43lickPlayerCardReply\x12\x0f\n\x07message\x18\x01 \x01(\t\"Y\n\x12\x43lickPlayerCardReq\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03\x61id\x18\x02 \x01(\x03\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\x12\x0e\n\x06\x61\x63tion\x18\x04 \x01(\x03\x12\r\n\x05spmid\x18\x05 \x01(\t\"2\n\x02\x43M\x12,\n\x0esource_content\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\"5\n\x08\x43MConfig\x12)\n\x0b\x61\x64s_control\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\"\xab\x01\n\x06\x43mIpad\x12$\n\x02\x63m\x18\x01 \x01(\x0b\x32\x18.bilibili.app.view.v1.CM\x12/\n\x06\x61uthor\x18\x02 \x01(\x0b\x32\x1f.bilibili.app.archive.v1.Author\x12+\n\x04stat\x18\x03 \x01(\x0b\x32\x1d.bilibili.app.archive.v1.Stat\x12\x10\n\x08\x64uration\x18\x04 \x01(\x03\x12\x0b\n\x03\x61id\x18\x05 \x01(\x03\"\x1b\n\nCoinCustom\x12\r\n\x05toast\x18\x01 \x01(\t\"\xa2\x01\n\tCommandDm\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x0b\n\x03mid\x18\x03 \x01(\x03\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\t\x12\x10\n\x08progress\x18\x06 \x01(\x05\x12\r\n\x05\x63time\x18\x07 \x01(\t\x12\r\n\x05mtime\x18\x08 \x01(\t\x12\r\n\x05\x65xtra\x18\t \x01(\t\x12\x0e\n\x06id_str\x18\n \x01(\t\"\xf8\x04\n\x06\x43onfig\x12\x15\n\rrelates_title\x18\x01 \x01(\t\x12\x15\n\rrelates_style\x18\x02 \x01(\x05\x12\x16\n\x0erelate_gif_exp\x18\x03 \x01(\x05\x12\x15\n\rend_page_half\x18\x04 \x01(\x05\x12\x15\n\rend_page_full\x18\x05 \x01(\x05\x12\x14\n\x0c\x61uto_swindow\x18\x06 \x01(\x08\x12\x12\n\npopup_info\x18\x07 \x01(\x08\x12\x1b\n\x13\x61\x62test_small_window\x18\x08 \x01(\t\x12\x1d\n\x15rec_three_point_style\x18\t \x01(\x05\x12\x18\n\x10is_absolute_time\x18\n \x01(\x08\x12\x13\n\x0bnew_swindow\x18\x0b \x01(\x08\x12\x18\n\x10relates_biserial\x18\x0c \x01(\x08\x12;\n\rlistener_conf\x18\r \x01(\x0b\x32$.bilibili.app.view.v1.ListenerConfig\x12\x1a\n\x12relates_feed_style\x18\x0e \x01(\t\x12\x1a\n\x12relates_feed_popup\x18\x0f \x01(\x08\x12\x18\n\x10relates_has_next\x18\x10 \x01(\x08\x12\x12\n\nlocal_play\x18\x11 \x01(\x05\x12\x12\n\nplay_story\x18\x12 \x01(\x08\x12\x16\n\x0e\x61rc_play_story\x18\x13 \x01(\x08\x12\x12\n\nstory_icon\x18\x14 \x01(\t\x12\x17\n\x0flandscape_story\x18\x15 \x01(\x08\x12\x1b\n\x13\x61rc_landscape_story\x18\x16 \x01(\x08\x12\x16\n\x0elandscape_icon\x18\x17 \x01(\t\x12\x1a\n\x12show_listen_button\x18\x18 \x01(\x08\"D\n\x13\x43ontinuousPlayReply\x12-\n\x07relates\x18\x01 \x03(\x0b\x32\x1c.bilibili.app.view.v1.Relate\"\xf6\x01\n\x11\x43ontinuousPlayReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x02 \x01(\t\x12\x0f\n\x07trackid\x18\x03 \x01(\t\x12\r\n\x05spmid\x18\x04 \x01(\t\x12\x12\n\nfrom_spmid\x18\x05 \x01(\t\x12\x10\n\x08\x61utoplay\x18\x06 \x01(\x05\x12\x43\n\x0bplayer_args\x18\x07 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x13\n\x0b\x64\x65vice_type\x18\x08 \x01(\x03\x12\x12\n\nsession_id\x18\t \x01(\t\x12\x12\n\ndisplay_id\x18\n \x01(\x03\"\xf8\x02\n\x0c\x43ontractCard\x12\x18\n\x10\x64isplay_progress\x18\x01 \x01(\x02\x12\x18\n\x10\x64isplay_accuracy\x18\x02 \x01(\x03\x12\x18\n\x10\x64isplay_duration\x18\x03 \x01(\x03\x12\x11\n\tshow_mode\x18\x04 \x01(\x05\x12\x11\n\tpage_type\x18\x05 \x01(\x05\x12/\n\x05upper\x18\x06 \x01(\x0b\x32 .bilibili.app.view.v1.UpperInfos\x12\x19\n\x11is_follow_display\x18\x07 \x01(\x05\x12\x30\n\x04text\x18\x08 \x01(\x0b\x32\".bilibili.app.view.v1.ContractText\x12#\n\x1b\x66ollow_display_end_duration\x18\t \x01(\x03\x12\x17\n\x0fis_play_display\x18\n \x01(\x05\x12\x1b\n\x13is_interact_display\x18\x0b \x01(\x05\x12\x1b\n\x13play_display_switch\x18\x0c \x01(\x08\"E\n\x0c\x43ontractText\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x14\n\x0cinline_title\x18\x03 \x01(\t\"\xe9\x01\n\x0f\x43reativeContent\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x14\n\x0c\x62utton_title\x18\x03 \x01(\t\x12\x10\n\x08video_id\x18\x04 \x01(\x03\x12\x10\n\x08username\x18\x05 \x01(\t\x12\x11\n\timage_url\x18\x06 \x01(\t\x12\x11\n\timage_md5\x18\x07 \x01(\t\x12\x0f\n\x07log_url\x18\x08 \x01(\t\x12\x0f\n\x07log_md5\x18\t \x01(\t\x12\x0b\n\x03url\x18\n \x01(\t\x12\x11\n\tclick_url\x18\x0b \x01(\t\x12\x10\n\x08show_url\x18\x0c \x01(\t\"$\n\x0c\x43ustomConfig\x12\x14\n\x0credirect_url\x18\x01 \x01(\t\"^\n\x06\x44\x65scV2\x12\x0c\n\x04text\x18\x01 \x01(\t\x12,\n\x04type\x18\x02 \x01(\x0e\x32\x1e.bilibili.app.view.v1.DescType\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0b\n\x03rid\x18\x04 \x01(\x03\"a\n\x07\x44islike\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x35\n\x07reasons\x18\x03 \x03(\x0b\x32$.bilibili.app.view.v1.DislikeReasons\"T\n\x0e\x44islikeReasons\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0b\n\x03rid\x18\x03 \x01(\x05\x12\x0e\n\x06tag_id\x18\x04 \x01(\x03\x12\x0c\n\x04name\x18\x05 \x01(\t\"6\n\x02\x44M\x12\x0e\n\x06\x63losed\x18\x01 \x01(\x08\x12\x11\n\treal_name\x18\x02 \x01(\x08\x12\r\n\x05\x63ount\x18\x03 \x01(\x03\"Y\n\x08\x45lecRank\x12\x30\n\x04list\x18\x01 \x03(\x0b\x32\".bilibili.app.view.v1.ElecRankItem\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\x12\x0c\n\x04text\x18\x03 \x01(\t\"N\n\x0c\x45lecRankItem\x12\x0e\n\x06\x61vatar\x18\x01 \x01(\t\x12\x10\n\x08nickname\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0b\n\x03mid\x18\x04 \x01(\x03\"\x9a\x03\n\x07\x45pisode\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0b\n\x03\x61id\x18\x02 \x01(\x03\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\x12\r\n\x05title\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x16\n\x0e\x63overRightText\x18\x06 \x01(\t\x12+\n\x04page\x18\x07 \x01(\x0b\x32\x1d.bilibili.app.archive.v1.Page\x12+\n\x04stat\x18\x08 \x01(\x0b\x32\x1d.bilibili.app.archive.v1.Stat\x12\x0c\n\x04\x62vid\x18\t \x01(\t\x12/\n\x06\x61uthor\x18\n \x01(\x0b\x32\x1f.bilibili.app.archive.v1.Author\x12\x13\n\x0b\x61uthor_desc\x18\x0b \x01(\t\x12\x35\n\x0b\x62\x61\x64ge_style\x18\x0c \x01(\x0b\x32 .bilibili.app.view.v1.BadgeStyle\x12\x10\n\x08need_pay\x18\r \x01(\x08\x12\x13\n\x0b\x65pisode_pay\x18\x0e \x01(\x08\x12\x12\n\nfree_watch\x18\x0f \x01(\x08\x12\x13\n\x0b\x66irst_frame\x18\x10 \x01(\t\"w\n\x13\x45xposePlayerCardReq\x12\x37\n\tcard_type\x18\x01 \x01(\x0e\x32$.bilibili.app.view.v1.PlayerCardType\x12\x0b\n\x03\x61id\x18\x02 \x01(\x03\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\x12\r\n\x05spmid\x18\x04 \x01(\t\"j\n\x0c\x46\x65\x65\x64ViewItem\x12-\n\x04view\x18\x01 \x01(\x0b\x32\x1f.bilibili.app.view.v1.ViewReply\x12\x0c\n\x04goto\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x10\n\x08track_id\x18\x04 \x01(\t\"S\n\rFeedViewReply\x12\x30\n\x04list\x18\x01 \x03(\x0b\x32\".bilibili.app.view.v1.FeedViewItem\x12\x10\n\x08has_next\x18\x02 \x01(\x08\"\xf3\x01\n\x0b\x46\x65\x65\x64ViewReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\x12\r\n\x05spmid\x18\x04 \x01(\t\x12\x12\n\nfrom_spmid\x18\x05 \x01(\t\x12\x43\n\x0bplayer_args\x18\x06 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\ndisplay_id\x18\x07 \x01(\x03\x12\x12\n\nsession_id\x18\x08 \x01(\t\x12\x14\n\x0cpage_version\x18\t \x01(\t\x12\x15\n\rfrom_track_id\x18\n \x01(\t\"K\n\x12GetArcsPlayerReply\x12\x35\n\x0b\x61rcs_player\x18\x01 \x03(\x0b\x32 .bilibili.app.view.v1.ArcsPlayer\"\x87\x01\n\x10GetArcsPlayerReq\x12.\n\x08play_avs\x18\x01 \x03(\x0b\x32\x1c.bilibili.app.view.v1.PlayAv\x12\x43\n\x0bplayer_args\x18\x02 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\"\x9e\x01\n\tGoodsInfo\x12\x10\n\x08goods_id\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\x05\x12\x13\n\x0bgoods_price\x18\x03 \x01(\x03\x12\x31\n\tpay_state\x18\x04 \x01(\x0e\x32\x1e.bilibili.app.view.v1.PayState\x12\x12\n\ngoods_name\x18\x05 \x01(\t\x12\x11\n\tprice_fmt\x18\x06 \x01(\t\"(\n\x07History\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\x12\x10\n\x08progress\x18\x02 \x01(\x03\"\xc2\x01\n\x05Honor\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x12\n\nicon_night\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x12\n\ntext_extra\x18\x04 \x01(\t\x12\x12\n\ntext_color\x18\x05 \x01(\t\x12\x18\n\x10text_color_night\x18\x06 \x01(\t\x12\x10\n\x08\x62g_color\x18\x07 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x08 \x01(\t\x12\x0b\n\x03url\x18\t \x01(\t\x12\x10\n\x08url_text\x18\n \x01(\t\"1\n\x08IconData\x12\x11\n\tmeta_json\x18\x01 \x01(\t\x12\x12\n\nsprits_img\x18\x02 \x01(\t\"\x85\x01\n\x0bInteraction\x12\x30\n\x0chistory_node\x18\x01 \x01(\x0b\x32\x1a.bilibili.app.view.v1.Node\x12\x15\n\rgraph_version\x18\x02 \x01(\x03\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\x12\n\nevaluation\x18\x04 \x01(\t\x12\x0c\n\x04mark\x18\x05 \x01(\x03\"\x93\x01\n\x05Label\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0b\n\x03uri\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x12\n\nicon_night\x18\x04 \x01(\t\x12\x12\n\nicon_width\x18\x05 \x01(\x03\x12\x13\n\x0bicon_height\x18\x06 \x01(\x03\x12\x0e\n\x06lottie\x18\x07 \x01(\t\x12\x14\n\x0clottie_night\x18\x08 \x01(\t\"N\n\rLikeAnimation\x12\x11\n\tlike_icon\x18\x01 \x01(\t\x12\x12\n\nliked_icon\x18\x02 \x01(\t\x12\x16\n\x0elike_animation\x18\x03 \x01(\t\"q\n\nLikeCustom\x12\x13\n\x0blike_switch\x18\x01 \x01(\x08\x12\x1d\n\x15\x66ull_to_half_progress\x18\x02 \x01(\x03\x12\x19\n\x11non_full_progress\x18\x03 \x01(\x03\x12\x14\n\x0cupdate_count\x18\x04 \x01(\x03\"_\n\x0eListenerConfig\x12\x12\n\njump_style\x18\x01 \x01(\x03\x12\x39\n\tguide_bar\x18\x02 \x01(\x0b\x32&.bilibili.app.view.v1.ListenerGuideBar\"\x83\x01\n\x10ListenerGuideBar\x12\x15\n\rshow_strategy\x18\x01 \x01(\x03\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x10\n\x08\x62tn_text\x18\x04 \x01(\t\x12\x11\n\tshow_time\x18\x05 \x01(\x03\x12\x17\n\x0f\x62\x61\x63kground_time\x18\x06 \x01(\x03\"E\n\x04Live\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0e\n\x06roomid\x18\x02 \x01(\x03\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x13\n\x0b\x65ndpage_uri\x18\x04 \x01(\t\"[\n\rLiveOrderInfo\x12\x0b\n\x03sid\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x1c\n\x14live_plan_start_time\x18\x03 \x01(\x03\x12\x11\n\tis_follow\x18\x04 \x01(\x08\"\x88\x01\n\x0cMaterialLeft\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x11\n\tleft_type\x18\x04 \x01(\t\x12\r\n\x05param\x18\x05 \x01(\t\x12\x18\n\x10operational_type\x18\x06 \x01(\t\x12\x13\n\x0bstatic_icon\x18\x07 \x01(\t\"\xab\x01\n\x0bMaterialRes\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x32\n\x04type\x18\x04 \x01(\x0e\x32$.bilibili.app.view.v1.MaterialSource\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08\x62g_color\x18\x06 \x01(\t\x12\x0e\n\x06\x62g_pic\x18\x07 \x01(\t\x12\x11\n\tjump_type\x18\x08 \x01(\x05\"3\n\x04Node\x12\x0f\n\x07node_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\"\t\n\x07NoReply\"%\n\x06Notice\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\",\n\x0eOfficialVerify\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"9\n\x06Online\x12\x13\n\x0bonline_show\x18\x01 \x01(\x08\x12\x1a\n\x12player_online_logo\x18\x02 \x01(\t\"\xcd\x01\n\x08OnwerExt\x12=\n\x0fofficial_verify\x18\x01 \x01(\x0b\x32$.bilibili.app.view.v1.OfficialVerify\x12(\n\x04live\x18\x02 \x01(\x0b\x32\x1a.bilibili.app.view.v1.Live\x12&\n\x03vip\x18\x03 \x01(\x0b\x32\x19.bilibili.app.view.v1.Vip\x12\x0f\n\x07\x61ssists\x18\x04 \x03(\x03\x12\x0c\n\x04\x66\x61ns\x18\x05 \x01(\x03\x12\x11\n\tarc_count\x18\x06 \x01(\t\"\x85\x01\n\rOperationCard\x12\x12\n\nstart_time\x18\x01 \x01(\x05\x12\x10\n\x08\x65nd_time\x18\x02 \x01(\x05\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x13\n\x0b\x62utton_text\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\t\"\xa7\x04\n\x10OperationCardNew\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x05\x12\n\n\x02to\x18\x03 \x01(\x05\x12\x0e\n\x06status\x18\x04 \x01(\x08\x12:\n\tcard_type\x18\x05 \x01(\x0e\x32\'.bilibili.app.view.v1.OperationCardType\x12\x36\n\x08standard\x18\x06 \x01(\x0b\x32\".bilibili.app.view.v1.StandardCardH\x00\x12\x33\n\x04skip\x18\x07 \x01(\x0b\x32#.bilibili.app.view.v1.OperationCardH\x00\x12/\n\x08\x62iz_type\x18\x08 \x01(\x0e\x32\x1d.bilibili.app.view.v1.BizType\x12;\n\x06\x66ollow\x18\t \x01(\x0b\x32).bilibili.app.view.v1.BizFollowVideoParamH\x01\x12@\n\x07reserve\x18\n \x01(\x0b\x32-.bilibili.app.view.v1.BizReserveActivityParamH\x01\x12\x36\n\x04jump\x18\x0b \x01(\x0b\x32&.bilibili.app.view.v1.BizJumpLinkParamH\x01\x12\x39\n\x04game\x18\x0c \x01(\x0b\x32).bilibili.app.view.v1.BizReserveGameParamH\x01\x42\x08\n\x06renderB\x07\n\x05param\"\xcb\x03\n\x0fOperationCardV2\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x05\x12\n\n\x02to\x18\x03 \x01(\x05\x12\x0e\n\x06status\x18\x04 \x01(\x08\x12\x10\n\x08\x62iz_type\x18\x05 \x01(\x05\x12=\n\x07\x63ontent\x18\x06 \x01(\x0b\x32,.bilibili.app.view.v1.OperationCardV2Content\x12H\n\x13\x42izFollowVideoParam\x18\x07 \x01(\x0b\x32).bilibili.app.view.v1.BizFollowVideoParamH\x00\x12P\n\x17\x42izReserveActivityParam\x18\x08 \x01(\x0b\x32-.bilibili.app.view.v1.BizReserveActivityParamH\x00\x12\x42\n\x10\x42izJumpLinkParam\x18\t \x01(\x0b\x32&.bilibili.app.view.v1.BizJumpLinkParamH\x00\x12H\n\x13\x42izReserveGameParam\x18\n \x01(\x0b\x32).bilibili.app.view.v1.BizReserveGameParamH\x00\x42\x07\n\x05param\"\x93\x01\n\x16OperationCardV2Content\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x14\n\x0c\x62utton_title\x18\x04 \x01(\t\x12\x1d\n\x15\x62utton_selected_title\x18\x05 \x01(\t\x12\x15\n\rshow_selected\x18\x06 \x01(\x08\"\x8d\x01\n\x0fOperationRelate\x12\r\n\x05title\x18\x01 \x01(\t\x12\x35\n\x0brelate_item\x18\x02 \x03(\x0b\x32 .bilibili.app.view.v1.RelateItem\x12\x34\n\x0e\x61i_relate_item\x18\x03 \x03(\x0b\x32\x1c.bilibili.app.view.v1.Relate\"\xe4\x02\n\x05Order\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\r\n\x05title\x18\x02 \x01(\t\x12\x14\n\x0c\x62utton_title\x18\x03 \x01(\t\x12\x1d\n\x15\x62utton_selected_title\x18\x04 \x01(\t\x12\x18\n\x10season_stat_view\x18\x05 \x01(\x03\x12\x1b\n\x13season_stat_danmaku\x18\x06 \x01(\x03\x12\x31\n\norder_type\x18\x07 \x01(\x0e\x32\x1d.bilibili.app.view.v1.BizType\x12@\n\x07reserve\x18\x08 \x01(\x0b\x32-.bilibili.app.view.v1.BizReserveActivityParamH\x00\x12=\n\nfav_season\x18\t \x01(\x0b\x32\'.bilibili.app.view.v1.BizFavSeasonParamH\x00\x12\r\n\x05intro\x18\n \x01(\tB\r\n\x0border_param\"&\n\x08PackInfo\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\"\n\x06PlayAv\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\"\xf1\x01\n\nPlayerIcon\x12\x0c\n\x04url1\x18\x01 \x01(\t\x12\r\n\x05hash1\x18\x02 \x01(\t\x12\x0c\n\x04url2\x18\x03 \x01(\t\x12\r\n\x05hash2\x18\x04 \x01(\t\x12\x15\n\rdrag_left_png\x18\x05 \x01(\t\x12\x12\n\nmiddle_png\x18\x06 \x01(\t\x12\x16\n\x0e\x64rag_right_png\x18\x07 \x01(\t\x12\x31\n\tdrag_data\x18\x08 \x01(\x0b\x32\x1e.bilibili.app.view.v1.IconData\x12\x33\n\x0bnodrag_data\x18\t \x01(\x0b\x32\x1e.bilibili.app.view.v1.IconData\"@\n\x12PlayerRelatesReply\x12*\n\x04list\x18\x01 \x03(\x0b\x32\x1c.bilibili.app.view.v1.Relate\"\xce\x01\n\x10PlayerRelatesReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\x12\r\n\x05spmid\x18\x04 \x01(\t\x12\x12\n\nfrom_spmid\x18\x05 \x01(\t\x12\x43\n\x0bplayer_args\x18\x06 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x12\n\nsession_id\x18\x07 \x01(\t\x12\x15\n\rfrom_track_id\x18\x08 \x01(\t\"5\n\rPointMaterial\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x17\n\x0fmaterial_source\x18\x02 \x01(\x05\"c\n\x0ePowerIconStyle\x12\x10\n\x08icon_url\x18\x01 \x01(\t\x12\x16\n\x0eicon_night_url\x18\x02 \x01(\t\x12\x12\n\nicon_width\x18\x03 \x01(\x03\x12\x13\n\x0bicon_height\x18\x04 \x01(\x03\"\x82\x01\n\x08Premiere\x12;\n\x0epremiere_state\x18\x01 \x01(\x0e\x32#.bilibili.app.view.v1.PremiereState\x12\x12\n\nstart_time\x18\x02 \x01(\x03\x12\x14\n\x0cservice_time\x18\x03 \x01(\x03\x12\x0f\n\x07room_id\x18\x04 \x01(\x03\"r\n\x14PremiereArchiveReply\x12\x30\n\x08premiere\x18\x01 \x01(\x0b\x32\x1e.bilibili.app.view.v1.Premiere\x12\x13\n\x0brisk_status\x18\x02 \x01(\x08\x12\x13\n\x0brisk_reason\x18\x03 \x01(\t\"!\n\x12PremiereArchiveReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\"G\n\x0fPremiereReserve\x12\x12\n\nreserve_id\x18\x01 \x01(\x03\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\x12\x11\n\tis_follow\x18\x03 \x01(\x08\"\xae\x01\n\x10PremiereResource\x12\x30\n\x08premiere\x18\x01 \x01(\x0b\x32\x1e.bilibili.app.view.v1.Premiere\x12\x36\n\x07reserve\x18\x02 \x01(\x0b\x32%.bilibili.app.view.v1.PremiereReserve\x12\x30\n\x04text\x18\x03 \x01(\x0b\x32\".bilibili.app.view.v1.PremiereText\"\xe9\x01\n\x0cPremiereText\x12\r\n\x05title\x18\x01 \x01(\t\x12\x10\n\x08subtitle\x18\x02 \x01(\t\x12\x13\n\x0bonline_text\x18\x03 \x01(\t\x12\x13\n\x0bonline_icon\x18\x04 \x01(\t\x12\x18\n\x10online_icon_dark\x18\x05 \x01(\t\x12\x13\n\x0bintro_title\x18\x06 \x01(\t\x12\x12\n\nintro_icon\x18\x07 \x01(\t\x12\x19\n\x11guidance_pulldown\x18\x08 \x01(\t\x12\x16\n\x0eguidance_entry\x18\t \x01(\t\x12\x18\n\x10intro_icon_night\x18\n \x01(\t\"E\n\x10PullClientAction\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x13\n\x0bpull_action\x18\x02 \x01(\x08\x12\x0e\n\x06params\x18\x03 \x01(\t\"6\n\x04Rank\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x12\n\nicon_night\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\"\xc3\x01\n\x08RankInfo\x12\x16\n\x0eicon_url_night\x18\x01 \x01(\t\x12\x14\n\x0cicon_url_day\x18\x02 \x01(\t\x12\x17\n\x0f\x62kg_night_color\x18\x03 \x01(\t\x12\x15\n\rbkg_day_color\x18\x04 \x01(\t\x12\x18\n\x10\x66ont_night_color\x18\x05 \x01(\t\x12\x16\n\x0e\x66ont_day_color\x18\x06 \x01(\t\x12\x14\n\x0crank_content\x18\x07 \x01(\t\x12\x11\n\trank_link\x18\x08 \x01(\t\"\xc9\x01\n\x0bReasonStyle\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x10\n\x08\x62g_color\x18\x03 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x04 \x01(\t\x12\x18\n\x10text_color_night\x18\x05 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x06 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x07 \x01(\t\x12\x10\n\x08\x62g_style\x18\x08 \x01(\x05\x12\x10\n\x08selected\x18\t \x01(\x05\"\xda\x01\n\nRecDislike\x12\r\n\x05title\x18\x01 \x01(\t\x12\x11\n\tsub_title\x18\x02 \x01(\t\x12\x18\n\x10\x63losed_sub_title\x18\x03 \x01(\t\x12\x12\n\npaste_text\x18\x04 \x01(\t\x12\x19\n\x11\x63losed_paste_text\x18\x05 \x01(\t\x12<\n\x0e\x64islike_reason\x18\x06 \x03(\x0b\x32$.bilibili.app.view.v1.DislikeReasons\x12\r\n\x05toast\x18\x07 \x01(\t\x12\x14\n\x0c\x63losed_toast\x18\x08 \x01(\t\"\x8b\x01\n\rRecThreePoint\x12\x31\n\x07\x64islike\x18\x01 \x01(\x0b\x32 .bilibili.app.view.v1.RecDislike\x12\x32\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x02 \x01(\x0b\x32 .bilibili.app.view.v1.RecDislike\x12\x13\n\x0bwatch_later\x18\x03 \x01(\x08\"d\n\x0bRefreshPage\x12\x13\n\x0brefreshable\x18\x01 \x01(\x05\x12\x14\n\x0crefresh_icon\x18\x02 \x01(\x05\x12\x14\n\x0crefresh_text\x18\x03 \x01(\t\x12\x14\n\x0crefresh_show\x18\x04 \x01(\x02\"\xc1\t\n\x06Relate\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03pic\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12/\n\x06\x61uthor\x18\x04 \x01(\x0b\x32\x1f.bilibili.app.archive.v1.Author\x12+\n\x04stat\x18\x05 \x01(\x0b\x32\x1d.bilibili.app.archive.v1.Stat\x12\x10\n\x08\x64uration\x18\x06 \x01(\x03\x12\x0c\n\x04goto\x18\x07 \x01(\t\x12\r\n\x05param\x18\x08 \x01(\t\x12\x0b\n\x03uri\x18\t \x01(\t\x12\x10\n\x08jump_url\x18\n \x01(\t\x12\x0e\n\x06rating\x18\x0b \x01(\x01\x12\x0f\n\x07reserve\x18\x0c \x01(\t\x12\x0c\n\x04\x66rom\x18\r \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x0e \x01(\t\x12\x13\n\x0brcmd_reason\x18\x0f \x01(\t\x12\r\n\x05\x62\x61\x64ge\x18\x10 \x01(\t\x12\x0b\n\x03\x63id\x18\x11 \x01(\x03\x12\x13\n\x0bseason_type\x18\x12 \x01(\x05\x12\x14\n\x0crating_count\x18\x13 \x01(\x05\x12\x10\n\x08tag_name\x18\x14 \x01(\t\x12\x31\n\tpack_info\x18\x15 \x01(\x0b\x32\x1e.bilibili.app.view.v1.PackInfo\x12,\n\x06notice\x18\x16 \x01(\x0b\x32\x1c.bilibili.app.view.v1.Notice\x12,\n\x06\x62utton\x18\x17 \x01(\x0b\x32\x1c.bilibili.app.view.v1.Button\x12\x0f\n\x07trackid\x18\x18 \x01(\t\x12\x10\n\x08new_card\x18\x19 \x01(\x05\x12<\n\x11rcmd_reason_style\x18\x1a \x01(\x0b\x32!.bilibili.app.view.v1.ReasonStyle\x12\x11\n\tcover_gif\x18\x1b \x01(\t\x12$\n\x02\x63m\x18\x1c \x01(\x0b\x32\x18.bilibili.app.view.v1.CM\x12\x16\n\x0ereserve_status\x18\x1d \x01(\x03\x12\x19\n\x11rcmd_reason_extra\x18\x1e \x01(\t\x12<\n\x0frec_three_point\x18\x1f \x01(\x0b\x32#.bilibili.app.view.v1.RecThreePoint\x12\x11\n\tunique_id\x18  \x01(\t\x12\x13\n\x0bmaterial_id\x18! \x01(\x03\x12\x18\n\x10\x66rom_source_type\x18\" \x01(\x03\x12\x16\n\x0e\x66rom_source_id\x18# \x01(\t\x12\x35\n\tdimension\x18$ \x01(\x0b\x32\".bilibili.app.archive.v1.Dimension\x12\r\n\x05\x63over\x18% \x01(\t\x12\x36\n\x0b\x62\x61\x64ge_style\x18& \x01(\x0b\x32!.bilibili.app.view.v1.ReasonStyle\x12>\n\x10power_icon_style\x18\' \x01(\x0b\x32$.bilibili.app.view.v1.PowerIconStyle\x12\x1b\n\x13reserve_status_text\x18( \x01(\t\x12\x1b\n\x13\x64islike_report_data\x18) \x01(\t\x12\x36\n\x0erank_info_game\x18* \x01(\x0b\x32\x1e.bilibili.app.view.v1.RankInfo\x12\x13\n\x0b\x66irst_frame\x18+ \x01(\t\"(\n\nRelateItem\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\r\n\x05\x63over\x18\x02 \x01(\t\"\x8a\x01\n\x10RelatesFeedReply\x12*\n\x04list\x18\x01 \x03(\x0b\x32\x1c.bilibili.app.view.v1.Relate\x12\x10\n\x08has_next\x18\x02 \x01(\x08\x12\x38\n\npagination\x18\x03 \x01(\x0b\x32$.bilibili.pagination.PaginationReply\"\xf8\x02\n\x0eRelatesFeedReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\x12\r\n\x05spmid\x18\x04 \x01(\t\x12\x12\n\nfrom_spmid\x18\x05 \x01(\t\x12\x43\n\x0bplayer_args\x18\x06 \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x14\n\x0crelates_page\x18\x07 \x01(\x03\x12\x12\n\nsession_id\x18\x08 \x01(\t\x12\x10\n\x08\x61utoplay\x18\t \x01(\x05\x12\x15\n\rfrom_track_id\x18\n \x01(\t\x12\x11\n\tbiz_extra\x18\x0b \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x0c \x01(\x03\x12\x10\n\x08\x61\x64_extra\x18\r \x01(\t\x12\x33\n\npagination\x18\x0e \x01(\x0b\x32\x1f.bilibili.pagination.Pagination\x12\x13\n\x0brefresh_num\x18\x0f \x01(\x05\"&\n\tRelateTab\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\"G\n\nReplyStyle\x12\x11\n\tbadge_url\x18\x01 \x01(\t\x12\x12\n\nbadge_text\x18\x02 \x01(\t\x12\x12\n\nbadge_type\x18\x03 \x01(\x03\"\xd6\x01\n\x07ReqUser\x12\x11\n\tattention\x18\x01 \x01(\x05\x12\x17\n\x0fguest_attention\x18\x02 \x01(\x05\x12\x10\n\x08\x66\x61vorite\x18\x03 \x01(\x05\x12\x0c\n\x04like\x18\x04 \x01(\x05\x12\x0f\n\x07\x64islike\x18\x05 \x01(\x05\x12\x0c\n\x04\x63oin\x18\x06 \x01(\x05\x12\x17\n\x0f\x61ttention_level\x18\x07 \x01(\x05\x12\x12\n\nfav_season\x18\x08 \x01(\x05\x12\x33\n\relec_plus_btn\x18\t \x01(\x0b\x32\x1c.bilibili.app.view.v1.Button\"\"\n\x0cReserveReply\x12\x12\n\nreserve_id\x18\x01 \x01(\x03\"G\n\nReserveReq\x12\x12\n\nreserve_id\x18\x01 \x01(\x03\x12\x16\n\x0ereserve_action\x18\x02 \x01(\x03\x12\r\n\x05up_id\x18\x03 \x01(\x03\"`\n\x0bRestriction\x12\x14\n\x0cis_teenagers\x18\x01 \x01(\x08\x12\x12\n\nis_lessons\x18\x02 \x01(\x08\x12\x11\n\tis_review\x18\x03 \x01(\x08\x12\x14\n\x0c\x64isable_rcmd\x18\x04 \x01(\x08\"\xca\x02\n\x06Season\x12\x16\n\x0e\x61llow_download\x18\x01 \x01(\t\x12\x11\n\tseason_id\x18\x02 \x01(\x03\x12\x0f\n\x07is_jump\x18\x03 \x01(\x05\x12\r\n\x05title\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x11\n\tis_finish\x18\x06 \x01(\x05\x12\x14\n\x0cnewest_ep_id\x18\x07 \x01(\x03\x12\x17\n\x0fnewest_ep_index\x18\x08 \x01(\t\x12\x13\n\x0btotal_count\x18\t \x01(\x03\x12\x0f\n\x07weekday\x18\n \x01(\x05\x12\x35\n\x0buser_season\x18\x0b \x01(\x0b\x32 .bilibili.app.view.v1.UserSeason\x12\x32\n\x06player\x18\x0c \x01(\x0b\x32\".bilibili.app.view.v1.SeasonPlayer\x12\x13\n\x0bogv_playurl\x18\r \x01(\t\"V\n\x19SeasonActivityRecordReply\x12\x39\n\x08\x61\x63tivity\x18\x01 \x01(\x0b\x32\'.bilibili.app.view.v1.UgcSeasonActivity\"\x89\x01\n\x17SeasonActivityRecordReq\x12\x11\n\tseason_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x61\x63tivity_id\x18\x02 \x01(\x03\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\x05\x12\x0b\n\x03\x61id\x18\x04 \x01(\x03\x12\x0b\n\x03\x63id\x18\x05 \x01(\x03\x12\r\n\x05scene\x18\x06 \x01(\x03\x12\r\n\x05spmid\x18\x07 \x01(\t\"C\n\x0cSeasonPlayer\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03vid\x18\x02 \x01(\t\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\x12\x0c\n\x04\x66rom\x18\x04 \x01(\t\">\n\x0bSeasonReply\x12/\n\x06season\x18\x01 \x01(\x0b\x32\x1f.bilibili.app.view.v1.UgcSeason\"\x1e\n\tSeasonReq\x12\x11\n\tseason_id\x18\x01 \x01(\x03\"u\n\nSeasonShow\x12\x13\n\x0b\x62utton_text\x18\x01 \x01(\t\x12\x11\n\tjoin_text\x18\x02 \x01(\t\x12\x11\n\trule_text\x18\x03 \x01(\t\x12\x14\n\x0c\x63heckin_text\x18\x04 \x01(\t\x12\x16\n\x0e\x63heckin_prompt\x18\x05 \x01(\t\"A\n\x17SeasonWidgetExposeReply\x12\x11\n\tseason_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x61\x63tivity_id\x18\x02 \x01(\x03\"\x83\x01\n\x15SeasonWidgetExposeReq\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\x11\n\tseason_id\x18\x03 \x01(\x03\x12\x13\n\x0b\x61\x63tivity_id\x18\x04 \x01(\x03\x12\x0b\n\x03\x61id\x18\x05 \x01(\x03\x12\x0b\n\x03\x63id\x18\x06 \x01(\x03\x12\r\n\x05scene\x18\x07 \x01(\x03\"c\n\x07Section\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x03\x12/\n\x08\x65pisodes\x18\x04 \x03(\x0b\x32\x1d.bilibili.app.view.v1.Episode\"\x85\x01\n\x1bShortFormVideoDownloadReply\x12\x18\n\x10has_download_url\x18\x01 \x01(\x08\x12\x14\n\x0c\x64ownload_url\x18\x02 \x01(\t\x12\x0b\n\x03md5\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\x03\x12\x1b\n\x13\x62\x61\x63kup_download_url\x18\x05 \x01(\t\"\xeb\x01\n\x19ShortFormVideoDownloadReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\x0b\n\x03mid\x18\x03 \x01(\x03\x12\r\n\x05\x62uvid\x18\x04 \x01(\t\x12\x10\n\x08mobi_app\x18\x05 \x01(\t\x12\r\n\x05\x62uild\x18\x06 \x01(\x03\x12\x0e\n\x06\x64\x65vice\x18\x07 \x01(\t\x12\x10\n\x08platform\x18\x08 \x01(\t\x12\r\n\x05spmid\x18\t \x01(\t\x12\x36\n\x0brestriction\x18\n \x01(\x0b\x32!.bilibili.app.view.v1.Restriction\x12\x0e\n\x06tf_isp\x18\x0b \x01(\t\"\xb7\x02\n\x0bSpecialCell\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x12\n\nicon_night\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x12\n\ntext_color\x18\x04 \x01(\t\x12\x18\n\x10text_color_night\x18\x05 \x01(\t\x12\x10\n\x08jump_url\x18\x06 \x01(\t\x12\x11\n\tcell_type\x18\x07 \x01(\t\x12\x14\n\x0c\x63\x65ll_bgcolor\x18\x08 \x01(\t\x12\x1a\n\x12\x63\x65ll_bgcolor_night\x18\t \x01(\t\x12\r\n\x05param\x18\n \x01(\t\x12\x12\n\npage_title\x18\x0b \x01(\t\x12\x11\n\tjump_type\x18\x0c \x01(\t\x12\x10\n\x08\x65nd_icon\x18\r \x01(\t\x12\x16\n\x0e\x65nd_icon_night\x18\x0e \x01(\t\x12\x13\n\x0bnotes_count\x18\x0f \x01(\x03\"\xce\x01\n\x05Staff\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12=\n\x0fofficial_verify\x18\x05 \x01(\x0b\x32$.bilibili.app.view.v1.OfficialVerify\x12&\n\x03vip\x18\x06 \x01(\x0b\x32\x19.bilibili.app.view.v1.Vip\x12\x11\n\tattention\x18\x07 \x01(\x05\x12\x13\n\x0blabel_style\x18\x08 \x01(\x05\"i\n\x0cStandardCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x14\n\x0c\x62utton_title\x18\x02 \x01(\t\x12\x1d\n\x15\x62utton_selected_title\x18\x03 \x01(\t\x12\x15\n\rshow_selected\x18\x04 \x01(\x08\"\x97\x01\n\nsubTFPanel\x12\x15\n\rright_btn_img\x18\x01 \x01(\t\x12\x16\n\x0eright_btn_text\x18\x02 \x01(\t\x12\x1c\n\x14right_btn_text_color\x18\x03 \x01(\t\x12\x16\n\x0eright_btn_link\x18\x04 \x01(\t\x12\x12\n\nmain_label\x18\x05 \x01(\t\x12\x10\n\x08operator\x18\x06 \x01(\t\"\x94\x02\n\x03Tab\x12\x12\n\nbackground\x18\x01 \x01(\t\x12-\n\x05otype\x18\x02 \x01(\x0e\x32\x1e.bilibili.app.view.v1.TabOtype\x12\x0b\n\x03oid\x18\x03 \x01(\x03\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12-\n\x05style\x18\x05 \x01(\x0e\x32\x1e.bilibili.app.view.v1.TabStyle\x12\x0c\n\x04text\x18\x06 \x01(\t\x12\x12\n\ntext_color\x18\x07 \x01(\t\x12\x1b\n\x13text_color_selected\x18\x08 \x01(\t\x12\x0b\n\x03pic\x18\t \x01(\t\x12\n\n\x02id\x18\n \x01(\x03\x12)\n\x0b\x61\x64_tab_info\x18\x0b \x01(\x0b\x32\x14.google.protobuf.Any\"z\n\x03Tag\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05likes\x18\x03 \x01(\x03\x12\r\n\x05hates\x18\x04 \x01(\x03\x12\r\n\x05liked\x18\x05 \x01(\x05\x12\r\n\x05hated\x18\x06 \x01(\x05\x12\x0b\n\x03uri\x18\x07 \x01(\t\x12\x10\n\x08tag_type\x18\x08 \x01(\t\"\xbb\x02\n\x11TFPanelCustomized\x12\x15\n\rright_btn_img\x18\x01 \x01(\t\x12\x16\n\x0eright_btn_text\x18\x02 \x01(\t\x12\x1c\n\x14right_btn_text_color\x18\x03 \x01(\t\x12\x16\n\x0eright_btn_link\x18\x04 \x01(\t\x12\x12\n\nmain_label\x18\x05 \x01(\t\x12\x10\n\x08operator\x18\x06 \x01(\t\x12H\n\tsub_panel\x18\x07 \x03(\x0b\x32\x35.bilibili.app.view.v1.TFPanelCustomized.SubPanelEntry\x1aQ\n\rSubPanelEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .bilibili.app.view.v1.subTFPanel:\x02\x38\x01\"\x15\n\x05TIcon\x12\x0c\n\x04icon\x18\x01 \x01(\t\"\xa2\x05\n\tUgcSeason\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x63over\x18\x03 \x01(\t\x12\r\n\x05intro\x18\x04 \x01(\t\x12/\n\x08sections\x18\x05 \x03(\x0b\x32\x1d.bilibili.app.view.v1.Section\x12\x31\n\x04stat\x18\x06 \x01(\x0b\x32#.bilibili.app.view.v1.UgcSeasonStat\x12\x12\n\nlabel_text\x18\x07 \x01(\t\x12\x18\n\x10label_text_color\x18\x08 \x01(\t\x12\x16\n\x0elabel_bg_color\x18\t \x01(\t\x12\x1e\n\x16label_text_night_color\x18\n \x01(\t\x12\x1c\n\x14label_bg_night_color\x18\x0b \x01(\t\x12\x11\n\tdescRight\x18\x0c \x01(\t\x12\x10\n\x08\x65p_count\x18\r \x01(\x03\x12\x35\n\x0bseason_type\x18\x0e \x01(\x0e\x32 .bilibili.app.view.v1.SeasonType\x12\x1d\n\x15show_continual_button\x18\x0f \x01(\x08\x12\x0e\n\x06\x65p_num\x18\x10 \x01(\x03\x12\x12\n\nseason_pay\x18\x11 \x01(\x08\x12\x33\n\ngoods_info\x18\x12 \x01(\x0b\x32\x1f.bilibili.app.view.v1.GoodsInfo\x12\x35\n\npay_button\x18\x13 \x01(\x0b\x32!.bilibili.app.view.v1.ButtonStyle\x12\x16\n\x0elabel_text_new\x18\x14 \x01(\t\x12\x39\n\x08\x61\x63tivity\x18\x15 \x01(\x0b\x32\'.bilibili.app.view.v1.UgcSeasonActivity\x12\x16\n\x0eseason_ability\x18\x16 \x03(\t\"\xdd\x02\n\x11UgcSeasonActivity\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0b\n\x03oid\x18\x02 \x01(\x03\x12\x13\n\x0b\x61\x63tivity_id\x18\x03 \x01(\x03\x12\r\n\x05title\x18\x04 \x01(\t\x12\r\n\x05intro\x18\x05 \x01(\t\x12\x11\n\tday_count\x18\x06 \x01(\x05\x12\x12\n\nuser_count\x18\x07 \x01(\x05\x12\x15\n\rjoin_deadline\x18\x08 \x01(\x03\x12\x19\n\x11\x61\x63tivity_deadline\x18\t \x01(\x03\x12\x19\n\x11\x63heckin_view_time\x18\n \x01(\x05\x12\x14\n\x0cnew_activity\x18\x0b \x01(\x08\x12\x39\n\ruser_activity\x18\x0c \x01(\x0b\x32\".bilibili.app.view.v1.UserActivity\x12\x35\n\x0bseason_show\x18\r \x01(\x0b\x32 .bilibili.app.view.v1.SeasonShow\"\xac\x01\n\rUgcSeasonStat\x12\x11\n\tseason_id\x18\x01 \x01(\x03\x12\x0c\n\x04view\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x61nmaku\x18\x03 \x01(\x05\x12\r\n\x05reply\x18\x04 \x01(\x05\x12\x0b\n\x03\x66\x61v\x18\x05 \x01(\x05\x12\x0c\n\x04\x63oin\x18\x06 \x01(\x05\x12\r\n\x05share\x18\x07 \x01(\x05\x12\x10\n\x08now_rank\x18\x08 \x01(\x05\x12\x10\n\x08his_rank\x18\t \x01(\x05\x12\x0c\n\x04like\x18\n \x01(\x05\"o\n\x05UpAct\x12\x0b\n\x03sid\x18\x01 \x01(\x03\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\r\n\x05title\x18\x03 \x01(\t\x12\x11\n\tstatement\x18\x04 \x01(\t\x12\r\n\x05image\x18\x05 \x01(\t\x12\x0b\n\x03url\x18\x06 \x01(\t\x12\x0e\n\x06\x62utton\x18\x07 \x01(\t\"L\n\tUpLikeImg\x12\x0f\n\x07pre_img\x18\x01 \x01(\t\x12\x0f\n\x07suc_img\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\x03\"t\n\nUpperInfos\x12\x12\n\nfans_count\x18\x01 \x01(\x03\x12 \n\x18\x61rc_count_last_half_year\x18\x02 \x01(\x03\x12\x16\n\x0e\x66irst_up_dates\x18\x03 \x01(\x03\x12\x18\n\x10total_play_count\x18\x04 \x01(\x03\"\x96\x01\n\x0cUserActivity\x12\x12\n\nuser_state\x18\x01 \x01(\x05\x12\x19\n\x11last_checkin_date\x18\x02 \x01(\x03\x12\x15\n\rcheckin_today\x18\x03 \x01(\x05\x12\x16\n\x0euser_day_count\x18\x04 \x01(\x05\x12\x16\n\x0euser_view_time\x18\x05 \x01(\x05\x12\x10\n\x08portrait\x18\x06 \x01(\t\"9\n\x08UserGarb\x12\x19\n\x11url_image_ani_cut\x18\x01 \x01(\t\x12\x12\n\nlike_toast\x18\x02 \x01(\t\"\x1f\n\nUserSeason\x12\x11\n\tattention\x18\x01 \x01(\t\"\xee\x02\n\nVideoGuide\x12\x32\n\tattention\x18\x01 \x03(\x0b\x32\x1f.bilibili.app.view.v1.Attention\x12\x33\n\ncommandDms\x18\x02 \x03(\x0b\x32\x1f.bilibili.app.view.v1.CommandDm\x12;\n\x0eoperation_card\x18\x03 \x03(\x0b\x32#.bilibili.app.view.v1.OperationCard\x12\x42\n\x12operation_card_new\x18\x04 \x03(\x0b\x32&.bilibili.app.view.v1.OperationCardNew\x12\x39\n\rcontract_card\x18\x05 \x01(\x0b\x32\".bilibili.app.view.v1.ContractCard\x12;\n\x0c\x63\x61rds_second\x18\x06 \x03(\x0b\x32%.bilibili.app.view.v1.OperationCardV2\"f\n\nVideoPoint\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x03\x12\n\n\x02to\x18\x03 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x10\n\x08logo_url\x18\x06 \x01(\t\"y\n\tVideoShot\x12\x0f\n\x07pv_data\x18\x01 \x01(\t\x12\x11\n\timg_x_len\x18\x02 \x01(\x05\x12\x11\n\timg_y_len\x18\x03 \x01(\x05\x12\x12\n\nimg_x_size\x18\x04 \x01(\x05\x12\x12\n\nimg_y_size\x18\x05 \x01(\x05\x12\r\n\x05image\x18\x06 \x03(\t\"Y\n\x0cViewMaterial\x12\x0b\n\x03oid\x18\x01 \x01(\x03\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\x12\x10\n\x08jump_url\x18\x05 \x01(\t\"\x87\x01\n\x11ViewMaterialReply\x12\x37\n\x0cmaterial_res\x18\x01 \x03(\x0b\x32!.bilibili.app.view.v1.MaterialRes\x12\x39\n\rmaterial_left\x18\x02 \x01(\x0b\x32\".bilibili.app.view.v1.MaterialLeft\"9\n\x0fViewMaterialReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\"\xbc\x01\n\x08ViewPage\x12+\n\x04page\x18\x01 \x01(\x0b\x32\x1d.bilibili.app.archive.v1.Page\x12*\n\x05\x61udio\x18\x02 \x01(\x0b\x32\x1b.bilibili.app.view.v1.Audio\x12$\n\x02\x64m\x18\x03 \x01(\x0b\x32\x18.bilibili.app.view.v1.DM\x12\x16\n\x0e\x64ownload_title\x18\x04 \x01(\t\x12\x19\n\x11\x64ownload_subtitle\x18\x05 \x01(\t\"\xf5\x02\n\x11ViewProgressReply\x12\x35\n\x0bvideo_guide\x18\x01 \x01(\x0b\x32 .bilibili.app.view.v1.VideoGuide\x12.\n\x07\x63hronos\x18\x02 \x01(\x0b\x32\x1d.bilibili.app.view.v1.Chronos\x12\x31\n\x08\x61rc_shot\x18\x03 \x01(\x0b\x32\x1f.bilibili.app.view.v1.VideoShot\x12\x30\n\x06points\x18\x04 \x03(\x0b\x32 .bilibili.app.view.v1.VideoPoint\x12;\n\x0epoint_material\x18\x05 \x01(\x0b\x32#.bilibili.app.view.v1.PointMaterial\x12\x17\n\x0fpoint_permanent\x18\x06 \x01(\x08\x12>\n\x10\x62uzzword_periods\x18\x07 \x03(\x0b\x32$.bilibili.app.view.v1.BuzzwordConfig\"\x82\x01\n\x0fViewProgressReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\x0e\n\x06up_mid\x18\x03 \x01(\x03\x12\x16\n\x0e\x65ngine_version\x18\x04 \x01(\t\x12\x18\n\x10message_protocol\x18\x05 \x01(\t\x12\x13\n\x0bservice_key\x18\x06 \x01(\t\"\xe1\x16\n\tViewReply\x12)\n\x03\x61rc\x18\x01 \x01(\x0b\x32\x1c.bilibili.app.archive.v1.Arc\x12-\n\x05pages\x18\x02 \x03(\x0b\x32\x1e.bilibili.app.view.v1.ViewPage\x12\x31\n\towner_ext\x18\x03 \x01(\x0b\x32\x1e.bilibili.app.view.v1.OnwerExt\x12/\n\x08req_user\x18\x04 \x01(\x0b\x32\x1d.bilibili.app.view.v1.ReqUser\x12&\n\x03tag\x18\x05 \x03(\x0b\x32\x19.bilibili.app.view.v1.Tag\x12:\n\x06t_icon\x18\x06 \x03(\x0b\x32*.bilibili.app.view.v1.ViewReply.TIconEntry\x12,\n\x06season\x18\x07 \x01(\x0b\x32\x1c.bilibili.app.view.v1.Season\x12\x31\n\telec_rank\x18\x08 \x01(\x0b\x32\x1e.bilibili.app.view.v1.ElecRank\x12.\n\x07history\x18\t \x01(\x0b\x32\x1d.bilibili.app.view.v1.History\x12-\n\x07relates\x18\n \x03(\x0b\x32\x1c.bilibili.app.view.v1.Relate\x12.\n\x07\x64islike\x18\x0b \x01(\x0b\x32\x1d.bilibili.app.view.v1.Dislike\x12\x35\n\x0bplayer_icon\x18\x0c \x01(\x0b\x32 .bilibili.app.view.v1.PlayerIcon\x12\x12\n\nvip_active\x18\r \x01(\t\x12\x0c\n\x04\x62vid\x18\x0e \x01(\t\x12*\n\x05honor\x18\x0f \x01(\x0b\x32\x1b.bilibili.app.view.v1.Honor\x12\x33\n\nrelate_tab\x18\x10 \x03(\x0b\x32\x1f.bilibili.app.view.v1.RelateTab\x12\x14\n\x0c\x61\x63tivity_url\x18\x11 \x01(\t\x12&\n\x03\x62gm\x18\x12 \x03(\x0b\x32\x19.bilibili.app.view.v1.Bgm\x12*\n\x05staff\x18\x13 \x03(\x0b\x32\x1b.bilibili.app.view.v1.Staff\x12\x11\n\targue_msg\x18\x14 \x01(\t\x12\x12\n\nshort_link\x18\x15 \x01(\t\x12\x12\n\nplay_param\x18\x16 \x01(\x05\x12*\n\x05label\x18\x17 \x01(\x0b\x32\x1b.bilibili.app.view.v1.Label\x12\x33\n\nugc_season\x18\x18 \x01(\x0b\x32\x1f.bilibili.app.view.v1.UgcSeason\x12,\n\x06\x63onfig\x18\x19 \x01(\x0b\x32\x1c.bilibili.app.view.v1.Config\x12\x16\n\x0eshare_subtitle\x18\x1a \x01(\t\x12\x36\n\x0binteraction\x18\x1b \x01(\x0b\x32!.bilibili.app.view.v1.Interaction\x12*\n\x05\x65\x63ode\x18\x1c \x01(\x0e\x32\x1b.bilibili.app.view.v1.ECode\x12\x39\n\rcustom_config\x18\x1d \x01(\x0b\x32\".bilibili.app.view.v1.CustomConfig\x12%\n\x03\x63ms\x18\x1e \x03(\x0b\x32\x18.bilibili.app.view.v1.CM\x12\x31\n\tcm_config\x18\x1f \x01(\x0b\x32\x1e.bilibili.app.view.v1.CMConfig\x12&\n\x03tab\x18  \x01(\x0b\x32\x19.bilibili.app.view.v1.Tab\x12(\n\x04rank\x18! \x01(\x0b\x32\x1a.bilibili.app.view.v1.Rank\x12\x44\n\x13tf_panel_customized\x18\" \x01(\x0b\x32\'.bilibili.app.view.v1.TFPanelCustomized\x12+\n\x06up_act\x18# \x01(\x0b\x32\x1b.bilibili.app.view.v1.UpAct\x12\x31\n\tuser_garb\x18$ \x01(\x0b\x32\x1e.bilibili.app.view.v1.UserGarb\x12=\n\x0f\x61\x63tivity_season\x18% \x01(\x0b\x32$.bilibili.app.view.v1.ActivitySeason\x12\x11\n\tbadge_url\x18& \x01(\t\x12<\n\x0flive_order_info\x18\' \x01(\x0b\x32#.bilibili.app.view.v1.LiveOrderInfo\x12-\n\x07\x64\x65sc_v2\x18( \x03(\x0b\x32\x1c.bilibili.app.view.v1.DescV2\x12-\n\x07\x63m_ipad\x18) \x01(\x0b\x32\x1c.bilibili.app.view.v1.CmIpad\x12\x33\n\x07sticker\x18* \x03(\x0b\x32\".bilibili.app.view.v1.ViewMaterial\x12\x34\n\x0bup_like_img\x18+ \x01(\x0b\x32\x1f.bilibili.app.view.v1.UpLikeImg\x12\x35\n\x0blike_custom\x18, \x01(\x0b\x32 .bilibili.app.view.v1.LikeCustom\x12+\n\x08\x64\x65sc_tag\x18- \x03(\x0b\x32\x19.bilibili.app.view.v1.Tag\x12\x37\n\x0cspecial_cell\x18. \x01(\x0b\x32!.bilibili.app.view.v1.SpecialCell\x12,\n\x06online\x18/ \x01(\x0b\x32\x1c.bilibili.app.view.v1.Online\x12-\n\x0f\x63m_under_player\x18\x30 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x38\n\x0cvideo_source\x18\x31 \x03(\x0b\x32\".bilibili.app.view.v1.ViewMaterial\x12;\n\x10special_cell_new\x18\x32 \x03(\x0b\x32!.bilibili.app.view.v1.SpecialCell\x12\x38\n\x08premiere\x18\x33 \x01(\x0b\x32&.bilibili.app.view.v1.PremiereResource\x12\x1c\n\x14refresh_special_cell\x18\x34 \x01(\x08\x12\x39\n\rmaterial_left\x18\x35 \x01(\x0b\x32\".bilibili.app.view.v1.MaterialLeft\x12\x13\n\x0bnotes_count\x18\x36 \x01(\x03\x12;\n\x0bpull_action\x18\x37 \x01(\x0b\x32&.bilibili.app.view.v1.PullClientAction\x12\x31\n\tarc_extra\x18\x38 \x01(\x0b\x32\x1e.bilibili.app.view.v1.ArcExtra\x12\x38\n\npagination\x18\x39 \x01(\x0b\x32$.bilibili.pagination.PaginationReply\x12;\n\x0elike_animation\x18: \x01(\x0b\x32#.bilibili.app.view.v1.LikeAnimation\x12\x37\n\rreply_preface\x18; \x01(\x0b\x32 .bilibili.app.view.v1.ReplyStyle\x12\x37\n\x0crefresh_page\x18< \x01(\x0b\x32!.bilibili.app.view.v1.RefreshPage\x12\x35\n\x0b\x63oin_custom\x18= \x01(\x0b\x32 .bilibili.app.view.v1.CoinCustom\x1aI\n\nTIconEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.bilibili.app.view.v1.TIcon:\x02\x38\x01\"\x88\x04\n\x07ViewReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\x0c\n\x04\x66rom\x18\x03 \x01(\t\x12\x0f\n\x07trackid\x18\x04 \x01(\t\x12\x10\n\x08\x61\x64_extra\x18\x05 \x01(\t\x12\n\n\x02qn\x18\x06 \x01(\x05\x12\r\n\x05\x66nver\x18\x07 \x01(\x05\x12\r\n\x05\x66nval\x18\x08 \x01(\x05\x12\x12\n\nforce_host\x18\t \x01(\x05\x12\r\n\x05\x66ourk\x18\n \x01(\x05\x12\r\n\x05spmid\x18\x0b \x01(\t\x12\x12\n\nfrom_spmid\x18\x0c \x01(\t\x12\x10\n\x08\x61utoplay\x18\r \x01(\x05\x12\x43\n\x0bplayer_args\x18\x0e \x01(\x0b\x32..bilibili.app.archive.middleware.v1.PlayerArgs\x12\x14\n\x0cpage_version\x18\x0f \x01(\t\x12\x11\n\tbiz_extra\x18\x10 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x11 \x01(\x03\x12\x14\n\x0crelates_page\x18\x12 \x01(\x03\x12\x12\n\nsession_id\x18\x13 \x01(\t\x12\x14\n\x0cin_feed_play\x18\x14 \x01(\x05\x12\x11\n\tplay_mode\x18\x15 \x01(\t\x12\x33\n\npagination\x18\x16 \x01(\x0b\x32\x1f.bilibili.pagination.Pagination\x12\x0f\n\x07refresh\x18\x17 \x01(\x05\x12\x13\n\x0brefresh_num\x18\x18 \x01(\x05\"\x86\x01\n\x0cViewTagReply\x12;\n\x10special_cell_new\x18\x01 \x03(\x0b\x32!.bilibili.app.view.v1.SpecialCell\x12\x39\n\rmaterial_left\x18\x02 \x01(\x0b\x32\".bilibili.app.view.v1.MaterialLeft\"C\n\nViewTagReq\x12\x0b\n\x03\x61id\x18\x01 \x01(\x03\x12\x0c\n\x04\x62vid\x18\x02 \x01(\t\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\x12\r\n\x05spmid\x18\x04 \x01(\t\"\xc0\x01\n\x03Vip\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x10\n\x08\x64ue_date\x18\x02 \x01(\x03\x12\x12\n\ndue_remark\x18\x03 \x01(\t\x12\x15\n\raccess_status\x18\x04 \x01(\x05\x12\x12\n\nvip_status\x18\x05 \x01(\x05\x12\x17\n\x0fvip_status_warn\x18\x06 \x01(\t\x12\x12\n\ntheme_type\x18\x07 \x01(\x05\x12-\n\x05label\x18\x08 \x01(\x0b\x32\x1e.bilibili.app.view.v1.VipLabel\";\n\x08VipLabel\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x13\n\x0blabel_theme\x18\x03 \x01(\t*\x91\x01\n\x07\x42izType\x12\x0f\n\x0b\x42izTypeNone\x10\x00\x12\x16\n\x12\x42izTypeFollowVideo\x10\x01\x12\x1a\n\x16\x42izTypeReserveActivity\x10\x02\x12\x13\n\x0f\x42izTypeJumpLink\x10\x03\x12\x14\n\x10\x42izTypeFavSeason\x10\x04\x12\x16\n\x12\x42izTypeReserveGame\x10\x05*3\n\x08\x43\x61tegory\x12\x13\n\x0f\x43\x61tegoryUnknown\x10\x00\x12\x12\n\x0e\x43\x61tegorySeason\x10\x01*A\n\x08\x44\x65scType\x12\x13\n\x0f\x44\x65scTypeUnknown\x10\x00\x12\x10\n\x0c\x44\x65scTypeText\x10\x01\x12\x0e\n\nDescTypeAt\x10\x02*!\n\x05\x45\x43ode\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0b\n\x07\x43ODE404\x10\x01*)\n\x0eMaterialSource\x12\x0b\n\x07\x44\x65\x66\x61ult\x10\x00\x12\n\n\x06\x42iJian\x10\x01*M\n\x11OperationCardType\x12\x10\n\x0c\x43\x61rdTypeNone\x10\x00\x12\x14\n\x10\x43\x61rdTypeStandard\x10\x01\x12\x10\n\x0c\x43\x61rdTypeSkip\x10\x02*3\n\x08PayState\x12\x13\n\x0fPayStateUnknown\x10\x00\x12\x12\n\x0ePayStateActive\x10\x01*\x96\x01\n\x0ePlayerCardType\x12\x1c\n\x18PlayerCardTypeNone_VALUE\x10\x00\x12!\n\x1dPlayerCardTypeAttention_VALUE\x10\x01\x12!\n\x1dPlayerCardTypeOperation_VALUE\x10\x02\x12 \n\x1cPlayerCardTypeContract_VALUE\x10\x03*\\\n\rPremiereState\x12\x11\n\rpremiere_none\x10\x00\x12\x13\n\x0fpremiere_before\x10\x01\x12\x0f\n\x0bpremiere_in\x10\x02\x12\x12\n\x0epremiere_after\x10\x03*-\n\nSeasonType\x12\x0b\n\x07Unknown\x10\x00\x12\x08\n\x04\x42\x61se\x10\x01\x12\x08\n\x04Good\x10\x02*=\n\x08TabOtype\x12\x10\n\x0cUnknownOtype\x10\x00\x12\x07\n\x03URL\x10\x01\x12\x0b\n\x07TopicNA\x10\x02\x12\t\n\x05\x43mURI\x10\x03*/\n\x08TabStyle\x12\x10\n\x0cUnknownStyle\x10\x00\x12\x08\n\x04Text\x10\x01\x12\x07\n\x03Pic\x10\x02\x32\xf3\x0e\n\x04View\x12\x46\n\x04View\x12\x1d.bilibili.app.view.v1.ViewReq\x1a\x1f.bilibili.app.view.v1.ViewReply\x12O\n\x07ViewTag\x12 .bilibili.app.view.v1.ViewTagReq\x1a\".bilibili.app.view.v1.ViewTagReply\x12^\n\x0cViewMaterial\x12%.bilibili.app.view.v1.ViewMaterialReq\x1a\'.bilibili.app.view.v1.ViewMaterialReply\x12^\n\x0cViewProgress\x12%.bilibili.app.view.v1.ViewProgressReq\x1a\'.bilibili.app.view.v1.ViewProgressReply\x12|\n\x16ShortFormVideoDownload\x12/.bilibili.app.view.v1.ShortFormVideoDownloadReq\x1a\x31.bilibili.app.view.v1.ShortFormVideoDownloadReply\x12Z\n\x0f\x43lickPlayerCard\x12(.bilibili.app.view.v1.ClickPlayerCardReq\x1a\x1d.bilibili.app.view.v1.NoReply\x12\x62\n\x13\x43lickActivitySeason\x12,.bilibili.app.view.v1.ClickActivitySeasonReq\x1a\x1d.bilibili.app.view.v1.NoReply\x12L\n\x06Season\x12\x1f.bilibili.app.view.v1.SeasonReq\x1a!.bilibili.app.view.v1.SeasonReply\x12\\\n\x10\x45xposePlayerCard\x12).bilibili.app.view.v1.ExposePlayerCardReq\x1a\x1d.bilibili.app.view.v1.NoReply\x12R\n\x0b\x41\x64\x64\x43ontract\x12$.bilibili.app.view.v1.AddContractReq\x1a\x1d.bilibili.app.view.v1.NoReply\x12P\n\nChronosPkg\x12#.bilibili.app.view.v1.ChronosPkgReq\x1a\x1d.bilibili.app.view.v1.Chronos\x12U\n\tCacheView\x12\".bilibili.app.view.v1.CacheViewReq\x1a$.bilibili.app.view.v1.CacheViewReply\x12\x64\n\x0e\x43ontinuousPlay\x12\'.bilibili.app.view.v1.ContinuousPlayReq\x1a).bilibili.app.view.v1.ContinuousPlayReply\x12[\n\x0bRelatesFeed\x12$.bilibili.app.view.v1.RelatesFeedReq\x1a&.bilibili.app.view.v1.RelatesFeedReply\x12g\n\x0fPremiereArchive\x12(.bilibili.app.view.v1.PremiereArchiveReq\x1a*.bilibili.app.view.v1.PremiereArchiveReply\x12O\n\x07Reserve\x12 .bilibili.app.view.v1.ReserveReq\x1a\".bilibili.app.view.v1.ReserveReply\x12\x61\n\rPlayerRelates\x12&.bilibili.app.view.v1.PlayerRelatesReq\x1a(.bilibili.app.view.v1.PlayerRelatesReply\x12v\n\x14SeasonActivityRecord\x12-.bilibili.app.view.v1.SeasonActivityRecordReq\x1a/.bilibili.app.view.v1.SeasonActivityRecordReply\x12p\n\x12SeasonWidgetExpose\x12+.bilibili.app.view.v1.SeasonWidgetExposeReq\x1a-.bilibili.app.view.v1.SeasonWidgetExposeReply\x12\x61\n\rGetArcsPlayer\x12&.bilibili.app.view.v1.GetArcsPlayerReq\x1a(.bilibili.app.view.v1.GetArcsPlayerReplyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.app.view.v1.view_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ARCSPLAYER_PLAYERINFOENTRY._options = None
  _ARCSPLAYER_PLAYERINFOENTRY._serialized_options = b'8\001'
  _TFPANELCUSTOMIZED_SUBPANELENTRY._options = None
  _TFPANELCUSTOMIZED_SUBPANELENTRY._serialized_options = b'8\001'
  _VIEWREPLY_TICONENTRY._options = None
  _VIEWREPLY_TICONENTRY._serialized_options = b'8\001'
  _BIZTYPE._serialized_start=27745
  _BIZTYPE._serialized_end=27890
  _CATEGORY._serialized_start=27892
  _CATEGORY._serialized_end=27943
  _DESCTYPE._serialized_start=27945
  _DESCTYPE._serialized_end=28010
  _ECODE._serialized_start=28012
  _ECODE._serialized_end=28045
  _MATERIALSOURCE._serialized_start=28047
  _MATERIALSOURCE._serialized_end=28088
  _OPERATIONCARDTYPE._serialized_start=28090
  _OPERATIONCARDTYPE._serialized_end=28167
  _PAYSTATE._serialized_start=28169
  _PAYSTATE._serialized_end=28220
  _PLAYERCARDTYPE._serialized_start=28223
  _PLAYERCARDTYPE._serialized_end=28373
  _PREMIERESTATE._serialized_start=28375
  _PREMIERESTATE._serialized_end=28467
  _SEASONTYPE._serialized_start=28469
  _SEASONTYPE._serialized_end=28514
  _TABOTYPE._serialized_start=28516
  _TABOTYPE._serialized_end=28577
  _TABSTYLE._serialized_start=28579
  _TABSTYLE._serialized_end=28626
  _ACTIVITYRESOURCE._serialized_start=212
  _ACTIVITYRESOURCE._serialized_end=419
  _ACTIVITYSEASON._serialized_start=422
  _ACTIVITYSEASON._serialized_end=1865
  _ADDCONTRACTREQ._serialized_start=1867
  _ADDCONTRACTREQ._serialized_end=1927
  _ADINFO._serialized_start=1930
  _ADINFO._serialized_end=2096
  _ARCEXTRA._serialized_start=2098
  _ARCEXTRA._serialized_end=2134
  _ARCSPLAYER._serialized_start=2137
  _ARCSPLAYER._serialized_end=2284
  _ARCSPLAYER_PLAYERINFOENTRY._serialized_start=2235
  _ARCSPLAYER_PLAYERINFOENTRY._serialized_end=2284
  _ASSET._serialized_start=2287
  _ASSET._serialized_end=2421
  _ASSETMSG._serialized_start=2423
  _ASSETMSG._serialized_end=2463
  _ATTENTION._serialized_start=2465
  _ATTENTION._serialized_end=2544
  _AUDIO._serialized_start=2547
  _AUDIO._serialized_end=2701
  _BADGESTYLE._serialized_start=2704
  _BADGESTYLE._serialized_end=2886
  _BGM._serialized_start=2888
  _BGM._serialized_end=2982
  _BIZFAVSEASONPARAM._serialized_start=2984
  _BIZFAVSEASONPARAM._serialized_end=3022
  _BIZFOLLOWVIDEOPARAM._serialized_start=3024
  _BIZFOLLOWVIDEOPARAM._serialized_end=3064
  _BIZJUMPLINKPARAM._serialized_start=3066
  _BIZJUMPLINKPARAM._serialized_end=3097
  _BIZRESERVEACTIVITYPARAM._serialized_start=3099
  _BIZRESERVEACTIVITYPARAM._serialized_end=3206
  _BIZRESERVEGAMEPARAM._serialized_start=3208
  _BIZRESERVEGAMEPARAM._serialized_end=3246
  _BUTTON._serialized_start=3248
  _BUTTON._serialized_end=3298
  _BUTTONSTYLE._serialized_start=3301
  _BUTTONSTYLE._serialized_end=3435
  _BUZZWORDCONFIG._serialized_start=3438
  _BUZZWORDCONFIG._serialized_end=3623
  _CACHEVIEWREPLY._serialized_start=3626
  _CACHEVIEWREPLY._serialized_end=4254
  _CACHEVIEWREQ._serialized_start=4256
  _CACHEVIEWREQ._serialized_end=4381
  _CHRONOS._serialized_start=4383
  _CHRONOS._serialized_end=4433
  _CHRONOSPKGREQ._serialized_start=4435
  _CHRONOSPKGREQ._serialized_end=4521
  _CLICKACTIVITYSEASONREQ._serialized_start=4524
  _CLICKACTIVITYSEASONREQ._serialized_end=4774
  _CLICKPLAYERCARDREPLY._serialized_start=4776
  _CLICKPLAYERCARDREPLY._serialized_end=4815
  _CLICKPLAYERCARDREQ._serialized_start=4817
  _CLICKPLAYERCARDREQ._serialized_end=4906
  _CM._serialized_start=4908
  _CM._serialized_end=4958
  _CMCONFIG._serialized_start=4960
  _CMCONFIG._serialized_end=5013
  _CMIPAD._serialized_start=5016
  _CMIPAD._serialized_end=5187
  _COINCUSTOM._serialized_start=5189
  _COINCUSTOM._serialized_end=5216
  _COMMANDDM._serialized_start=5219
  _COMMANDDM._serialized_end=5381
  _CONFIG._serialized_start=5384
  _CONFIG._serialized_end=6016
  _CONTINUOUSPLAYREPLY._serialized_start=6018
  _CONTINUOUSPLAYREPLY._serialized_end=6086
  _CONTINUOUSPLAYREQ._serialized_start=6089
  _CONTINUOUSPLAYREQ._serialized_end=6335
  _CONTRACTCARD._serialized_start=6338
  _CONTRACTCARD._serialized_end=6714
  _CONTRACTTEXT._serialized_start=6716
  _CONTRACTTEXT._serialized_end=6785
  _CREATIVECONTENT._serialized_start=6788
  _CREATIVECONTENT._serialized_end=7021
  _CUSTOMCONFIG._serialized_start=7023
  _CUSTOMCONFIG._serialized_end=7059
  _DESCV2._serialized_start=7061
  _DESCV2._serialized_end=7155
  _DISLIKE._serialized_start=7157
  _DISLIKE._serialized_end=7254
  _DISLIKEREASONS._serialized_start=7256
  _DISLIKEREASONS._serialized_end=7340
  _DM._serialized_start=7342
  _DM._serialized_end=7396
  _ELECRANK._serialized_start=7398
  _ELECRANK._serialized_end=7487
  _ELECRANKITEM._serialized_start=7489
  _ELECRANKITEM._serialized_end=7567
  _EPISODE._serialized_start=7570
  _EPISODE._serialized_end=7980
  _EXPOSEPLAYERCARDREQ._serialized_start=7982
  _EXPOSEPLAYERCARDREQ._serialized_end=8101
  _FEEDVIEWITEM._serialized_start=8103
  _FEEDVIEWITEM._serialized_end=8209
  _FEEDVIEWREPLY._serialized_start=8211
  _FEEDVIEWREPLY._serialized_end=8294
  _FEEDVIEWREQ._serialized_start=8297
  _FEEDVIEWREQ._serialized_end=8540
  _GETARCSPLAYERREPLY._serialized_start=8542
  _GETARCSPLAYERREPLY._serialized_end=8617
  _GETARCSPLAYERREQ._serialized_start=8620
  _GETARCSPLAYERREQ._serialized_end=8755
  _GOODSINFO._serialized_start=8758
  _GOODSINFO._serialized_end=8916
  _HISTORY._serialized_start=8918
  _HISTORY._serialized_end=8958
  _HONOR._serialized_start=8961
  _HONOR._serialized_end=9155
  _ICONDATA._serialized_start=9157
  _ICONDATA._serialized_end=9206
  _INTERACTION._serialized_start=9209
  _INTERACTION._serialized_end=9342
  _LABEL._serialized_start=9345
  _LABEL._serialized_end=9492
  _LIKEANIMATION._serialized_start=9494
  _LIKEANIMATION._serialized_end=9572
  _LIKECUSTOM._serialized_start=9574
  _LIKECUSTOM._serialized_end=9687
  _LISTENERCONFIG._serialized_start=9689
  _LISTENERCONFIG._serialized_end=9784
  _LISTENERGUIDEBAR._serialized_start=9787
  _LISTENERGUIDEBAR._serialized_end=9918
  _LIVE._serialized_start=9920
  _LIVE._serialized_end=9989
  _LIVEORDERINFO._serialized_start=9991
  _LIVEORDERINFO._serialized_end=10082
  _MATERIALLEFT._serialized_start=10085
  _MATERIALLEFT._serialized_end=10221
  _MATERIALRES._serialized_start=10224
  _MATERIALRES._serialized_end=10395
  _NODE._serialized_start=10397
  _NODE._serialized_end=10448
  _NOREPLY._serialized_start=10450
  _NOREPLY._serialized_end=10459
  _NOTICE._serialized_start=10461
  _NOTICE._serialized_end=10498
  _OFFICIALVERIFY._serialized_start=10500
  _OFFICIALVERIFY._serialized_end=10544
  _ONLINE._serialized_start=10546
  _ONLINE._serialized_end=10603
  _ONWEREXT._serialized_start=10606
  _ONWEREXT._serialized_end=10811
  _OPERATIONCARD._serialized_start=10814
  _OPERATIONCARD._serialized_end=10947
  _OPERATIONCARDNEW._serialized_start=10950
  _OPERATIONCARDNEW._serialized_end=11501
  _OPERATIONCARDV2._serialized_start=11504
  _OPERATIONCARDV2._serialized_end=11963
  _OPERATIONCARDV2CONTENT._serialized_start=11966
  _OPERATIONCARDV2CONTENT._serialized_end=12113
  _OPERATIONRELATE._serialized_start=12116
  _OPERATIONRELATE._serialized_end=12257
  _ORDER._serialized_start=12260
  _ORDER._serialized_end=12616
  _PACKINFO._serialized_start=12618
  _PACKINFO._serialized_end=12656
  _PLAYAV._serialized_start=12658
  _PLAYAV._serialized_end=12692
  _PLAYERICON._serialized_start=12695
  _PLAYERICON._serialized_end=12936
  _PLAYERRELATESREPLY._serialized_start=12938
  _PLAYERRELATESREPLY._serialized_end=13002
  _PLAYERRELATESREQ._serialized_start=13005
  _PLAYERRELATESREQ._serialized_end=13211
  _POINTMATERIAL._serialized_start=13213
  _POINTMATERIAL._serialized_end=13266
  _POWERICONSTYLE._serialized_start=13268
  _POWERICONSTYLE._serialized_end=13367
  _PREMIERE._serialized_start=13370
  _PREMIERE._serialized_end=13500
  _PREMIEREARCHIVEREPLY._serialized_start=13502
  _PREMIEREARCHIVEREPLY._serialized_end=13616
  _PREMIEREARCHIVEREQ._serialized_start=13618
  _PREMIEREARCHIVEREQ._serialized_end=13651
  _PREMIERERESERVE._serialized_start=13653
  _PREMIERERESERVE._serialized_end=13724
  _PREMIERERESOURCE._serialized_start=13727
  _PREMIERERESOURCE._serialized_end=13901
  _PREMIERETEXT._serialized_start=13904
  _PREMIERETEXT._serialized_end=14137
  _PULLCLIENTACTION._serialized_start=14139
  _PULLCLIENTACTION._serialized_end=14208
  _RANK._serialized_start=14210
  _RANK._serialized_end=14264
  _RANKINFO._serialized_start=14267
  _RANKINFO._serialized_end=14462
  _REASONSTYLE._serialized_start=14465
  _REASONSTYLE._serialized_end=14666
  _RECDISLIKE._serialized_start=14669
  _RECDISLIKE._serialized_end=14887
  _RECTHREEPOINT._serialized_start=14890
  _RECTHREEPOINT._serialized_end=15029
  _REFRESHPAGE._serialized_start=15031
  _REFRESHPAGE._serialized_end=15131
  _RELATE._serialized_start=15134
  _RELATE._serialized_end=16351
  _RELATEITEM._serialized_start=16353
  _RELATEITEM._serialized_end=16393
  _RELATESFEEDREPLY._serialized_start=16396
  _RELATESFEEDREPLY._serialized_end=16534
  _RELATESFEEDREQ._serialized_start=16537
  _RELATESFEEDREQ._serialized_end=16913
  _RELATETAB._serialized_start=16915
  _RELATETAB._serialized_end=16953
  _REPLYSTYLE._serialized_start=16955
  _REPLYSTYLE._serialized_end=17026
  _REQUSER._serialized_start=17029
  _REQUSER._serialized_end=17243
  _RESERVEREPLY._serialized_start=17245
  _RESERVEREPLY._serialized_end=17279
  _RESERVEREQ._serialized_start=17281
  _RESERVEREQ._serialized_end=17352
  _RESTRICTION._serialized_start=17354
  _RESTRICTION._serialized_end=17450
  _SEASON._serialized_start=17453
  _SEASON._serialized_end=17783
  _SEASONACTIVITYRECORDREPLY._serialized_start=17785
  _SEASONACTIVITYRECORDREPLY._serialized_end=17871
  _SEASONACTIVITYRECORDREQ._serialized_start=17874
  _SEASONACTIVITYRECORDREQ._serialized_end=18011
  _SEASONPLAYER._serialized_start=18013
  _SEASONPLAYER._serialized_end=18080
  _SEASONREPLY._serialized_start=18082
  _SEASONREPLY._serialized_end=18144
  _SEASONREQ._serialized_start=18146
  _SEASONREQ._serialized_end=18176
  _SEASONSHOW._serialized_start=18178
  _SEASONSHOW._serialized_end=18295
  _SEASONWIDGETEXPOSEREPLY._serialized_start=18297
  _SEASONWIDGETEXPOSEREPLY._serialized_end=18362
  _SEASONWIDGETEXPOSEREQ._serialized_start=18365
  _SEASONWIDGETEXPOSEREQ._serialized_end=18496
  _SECTION._serialized_start=18498
  _SECTION._serialized_end=18597
  _SHORTFORMVIDEODOWNLOADREPLY._serialized_start=18600
  _SHORTFORMVIDEODOWNLOADREPLY._serialized_end=18733
  _SHORTFORMVIDEODOWNLOADREQ._serialized_start=18736
  _SHORTFORMVIDEODOWNLOADREQ._serialized_end=18971
  _SPECIALCELL._serialized_start=18974
  _SPECIALCELL._serialized_end=19285
  _STAFF._serialized_start=19288
  _STAFF._serialized_end=19494
  _STANDARDCARD._serialized_start=19496
  _STANDARDCARD._serialized_end=19601
  _SUBTFPANEL._serialized_start=19604
  _SUBTFPANEL._serialized_end=19755
  _TAB._serialized_start=19758
  _TAB._serialized_end=20034
  _TAG._serialized_start=20036
  _TAG._serialized_end=20158
  _TFPANELCUSTOMIZED._serialized_start=20161
  _TFPANELCUSTOMIZED._serialized_end=20476
  _TFPANELCUSTOMIZED_SUBPANELENTRY._serialized_start=20395
  _TFPANELCUSTOMIZED_SUBPANELENTRY._serialized_end=20476
  _TICON._serialized_start=20478
  _TICON._serialized_end=20499
  _UGCSEASON._serialized_start=20502
  _UGCSEASON._serialized_end=21176
  _UGCSEASONACTIVITY._serialized_start=21179
  _UGCSEASONACTIVITY._serialized_end=21528
  _UGCSEASONSTAT._serialized_start=21531
  _UGCSEASONSTAT._serialized_end=21703
  _UPACT._serialized_start=21705
  _UPACT._serialized_end=21816
  _UPLIKEIMG._serialized_start=21818
  _UPLIKEIMG._serialized_end=21894
  _UPPERINFOS._serialized_start=21896
  _UPPERINFOS._serialized_end=22012
  _USERACTIVITY._serialized_start=22015
  _USERACTIVITY._serialized_end=22165
  _USERGARB._serialized_start=22167
  _USERGARB._serialized_end=22224
  _USERSEASON._serialized_start=22226
  _USERSEASON._serialized_end=22257
  _VIDEOGUIDE._serialized_start=22260
  _VIDEOGUIDE._serialized_end=22626
  _VIDEOPOINT._serialized_start=22628
  _VIDEOPOINT._serialized_end=22730
  _VIDEOSHOT._serialized_start=22732
  _VIDEOSHOT._serialized_end=22853
  _VIEWMATERIAL._serialized_start=22855
  _VIEWMATERIAL._serialized_end=22944
  _VIEWMATERIALREPLY._serialized_start=22947
  _VIEWMATERIALREPLY._serialized_end=23082
  _VIEWMATERIALREQ._serialized_start=23084
  _VIEWMATERIALREQ._serialized_end=23141
  _VIEWPAGE._serialized_start=23144
  _VIEWPAGE._serialized_end=23332
  _VIEWPROGRESSREPLY._serialized_start=23335
  _VIEWPROGRESSREPLY._serialized_end=23708
  _VIEWPROGRESSREQ._serialized_start=23711
  _VIEWPROGRESSREQ._serialized_end=23841
  _VIEWREPLY._serialized_start=23844
  _VIEWREPLY._serialized_end=26757
  _VIEWREPLY_TICONENTRY._serialized_start=26684
  _VIEWREPLY_TICONENTRY._serialized_end=26757
  _VIEWREQ._serialized_start=26760
  _VIEWREQ._serialized_end=27280
  _VIEWTAGREPLY._serialized_start=27283
  _VIEWTAGREPLY._serialized_end=27417
  _VIEWTAGREQ._serialized_start=27419
  _VIEWTAGREQ._serialized_end=27486
  _VIP._serialized_start=27489
  _VIP._serialized_end=27681
  _VIPLABEL._serialized_start=27683
  _VIPLABEL._serialized_end=27742
  _VIEW._serialized_start=28629
  _VIEW._serialized_end=30536
# @@protoc_insertion_point(module_scope)
